var GreenletOptions = (function () {
	'use strict';

	var styles = ":root{--accent: #23b887}.appearance_page_greenlet #wpcontent{padding:0}.appearance_page_greenlet .update-nag{margin:0;display:block}#greenlet,#greenlet *,#greenlet *::before,#greenlet *::after{box-sizing:border-box}#greenlet{margin:0}#greenlet .title{padding:20px;background:var(--accent);color:#fff;font-size:18px;font-weight:100;text-align:center}#greenlet-options{padding-top:20px;font-size:14px}.container{position:relative;margin:0 auto;padding:0 20px}.container:after,.row:after,.clearfix{content:'';display:table;clear:both}.row{margin-right:-15px;margin-left:-15px}.col-1,.col-2,.col-3,.col-4,.col-5,.col-6,.col-7,.col-8,.col-9,.col-10,.col-11,.col-12{margin:0;width:100%;float:left;padding:0 15px}@media (min-width: 801px){.col-1{width:8.33333333333%}.col-2{width:16.6666666667%}.col-3{width:25%}.col-4{width:33.3333333333%}.col-5{width:41.6666666667%}.col-6{width:50%}.col-7{width:58.3333333333%}.col-8{width:66.6666666667%}.col-9{width:75%}.col-10{width:83.3333333333%}.col-11{width:91.6666666667%}.col-12{width:100%}}#greenlet-options a{text-decoration:none}#greenlet-options a .dashicons{margin-right:10px;background-color:#0171a1;background-image:linear-gradient(60deg, #01a0e4, #0171a1);background-size:100%;background-repeat:repeat;-webkit-background-clip:text;-webkit-text-fill-color:transparent}#greenlet-options .heading{font-weight:500;padding:10px 15px;border-bottom:1px solid #ddd}#greenlet-options .link,#greenlet-options .plugin{padding:10px 15px;border-bottom:1px solid #eee;position:relative}#greenlet-options .content-wrap{padding:15px 15px 30px;position:relative;overflow:hidden}#greenlet-options .btn-wrap{padding-top:15px}#greenlet-options .explain{color:#999;font-size:12px;padding-top:10px;float:left}#greenlet-options .action-btn{float:right}#greenlet-options .message{position:absolute;bottom:0;width:100%;max-height:0;background:#666;color:#fff;padding:2px;font-size:12px;text-align:center;visibility:hidden;opacity:0;transition:all 0.5s}#greenlet-options .message.show{visibility:visible;opacity:1;max-height:50px}#greenlet-options .message.success{background:var(--accent)}#greenlet-options .message.warning{background:#FFF59D;color:#827717}#greenlet-options .message.error{background:#cb000b}#greenlet-options .settings,#greenlet-options .plugins,#greenlet-options .impex{background:#fff;border:1px solid #ccc;box-shadow:0 1px 1px rgba(0,0,0,0.05);margin-bottom:20px}#greenlet-options .setting-description{font-size:13px;padding-top:5px}#greenlet-options .impex .sub-heading{margin-bottom:10px}#greenlet-options .impex textarea{width:100%;color:#666;background:#f9f9f9;display:block}#greenlet-options .plugin .message{width:fit-content;right:120px;padding:10px;text-transform:capitalize;background:none;color:#0073aa}.plugin-op{float:right;text-transform:capitalize;position:relative}.plugin-op .spinner{position:absolute;right:100%;margin-top:0;background-size:18px}.plugin-op.running{pointer-events:none;color:#999}.plugin-op.running .spinner{visibility:visible}.ext-links{margin-bottom:10px}.ext-links .link-wrap a{padding:10px 0;display:block}\n";

	/**
	 * Custom scripts needed for options.
	 *
	 * @package greenlet\library\backend\assets\js
	 */
	/**
	 * Show Temporary Message.
	 *
	 * @param {string|Element} selector Class Name.
	 * @param {number}         delay    Delay in microseconds.
	 * @param {string|bool}    message  Message HTML or text.
	 */

	function showTemporaryMessage(selector) {
	  var delay = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 5000;
	  var message = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;

	  if ('string' === typeof selector) {
	    selector = document.querySelector(selector);
	  }

	  if (false !== message) {
	    selector.innerHTML = message;
	  }

	  selector.classList.add('show');
	  setTimeout(function () {
	    return selector.classList.remove('show');
	  }, delay);
	}

	function domReady(callback) {
	  if (document.readyState === 'complete' || document.readyState === 'interactive') return void callback();
	  document.addEventListener('DOMContentLoaded', callback);
	}

	function addStyles() {
	  var style = document.createElement('style');
	  style.id = 'greenlet-options';
	  style.innerHTML = styles;
	  document.body.appendChild(style);
	}

	function post(args) {
	  var inHeaders = args.headers || {};
	  var headers = {
	    'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8'
	  };
	  Object.assign(headers, inHeaders);
	  var body = Object.keys(args.body).map(function (k) {
	    return "".concat(encodeURIComponent(k), "=").concat(encodeURIComponent(args.body[k]));
	  }).join('&');
	  return fetch(args.url, {
	    method: 'POST',
	    headers: headers,
	    body: body
	  }).then(function (r) {
	    return r.json();
	  });
	}

	function togglePlugin(target, op) {
	  var body = {
	    action: 'greenlet_toggle_plugin',
	    op: op,
	    nonce: glOptionsData.nonce,
	    plugin: target.dataset.plugin
	  };
	  var message = target.previousElementSibling;
	  post({
	    url: glOptionsData.ajaxUrl,
	    method: 'POST',
	    body: body
	  }).then(function (res) {
	    if (res.data.success) {
	      var newOp = 'activate' === op ? 'deactivate' : 'activate';
	      target.dataset.op = newOp;
	      target.innerHTML = "<span class=\"spinner\"></span> ".concat(newOp);
	      showTemporaryMessage(message, 3000, "".concat(op, "d successfully"));
	      location.reload();
	    } else {
	      showTemporaryMessage(message, 3000, "".concat(op, " failed. Please try again"));
	    }
	  })["catch"](function (err) {
	    showTemporaryMessage(message, 3000, "".concat(op, " failed. Please try again"));
	  })["finally"](function () {
	    return target.classList.remove('running');
	  });
	}

	function managePluginOp(e) {
	  if (!e.target.classList.contains('plugin-op')) return;
	  e.preventDefault();
	  var message = e.target.previousElementSibling;
	  e.target.classList.add('running');

	  if ('install-activate' === e.target.dataset.op) {
	    if (wp.updates.shouldRequestFilesystemCredentials && !wp.updates.ajaxLocked) {
	      wp.updates.requestFilesystemCredentials(e);
	      jQuery(document).on('credential-modal-cancel', function () {
	        showTemporaryMessage(message, 3000, wp.updates.l10n.installNow);
	      });
	    }

	    wp.updates.installPlugin({
	      slug: e.target.dataset.slug
	    }).then(function (res) {
	      if ('activateUrl' in res) {
	        togglePlugin(e.target, 'activate');
	      } else {
	        showTemporaryMessage(message, 3000, 'Installation failed. Please try again');
	        e.target.classList.remove('running');
	      }
	    })["catch"](function (err) {
	      showTemporaryMessage(message, 3000, 'Installation failed. Please try again');
	      e.target.classList.remove('running');
	    });
	  } else if ('activate' === e.target.dataset.op) {
	    togglePlugin(e.target, 'activate');
	  } else if ('deactivate' === e.target.dataset.op) {
	    togglePlugin(e.target, 'deactivate');
	  }
	}

	function initPluginOps() {
	  var plugins = document.getElementsByClassName('greenlet-plugins');
	  if (0 === plugins.length) return;
	  plugins[0].addEventListener('click', managePluginOp);
	}
	/**
	 * Fill XHR HTML Section.
	 */


	function fillXhrSection() {
	  var url = 'https://greenletwp.com/wp-json/greenlet/api-section';
	  var xhrSection = document.getElementById('xhr-section');
	  fetch(url).then(function (r) {
	    return r.json();
	  }).then(function (res) {
	    return xhrSection.innerHTML = res.html;
	  })["catch"](function (err) {
	    return console.log(err);
	  });
	}

	function init() {
	  addStyles();
	  initPluginOps();
	  fillXhrSection();
	}

	domReady(init);
	var greenletOptions = {
	  showTemporaryMessage: showTemporaryMessage,
	  post: post
	};

	return greenletOptions;

}());
//# sourceMappingURL=greenlet-options.js.map
